#!/bin/bash
#
# Copyright (C) 2017  Tetras Libre <admin@tetras-libre.fr>
# Author: Curt, Sebastien <sebastien.curt@tetras-libre.fr>
#
# This program is free software: you can redistribute it and/or modify # it
# under the terms of the GNU General Public License as published by # the Free
# Software Foundation, either version 3 of the License, or # (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, # but WITHOUT
# ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the # GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License # along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

set -o nounset                              # Treat unset variables as an error

echo "RUN $(basename "$0") ==="

DIR=$(realpath $(dirname $0)/..)
if [ ! -e $DIR/main.env ]
then
    echo "Please copy in root of NoCloud Auto Installer main.env.sample to main.env and edit it"
    exit 1
else
    echo "Environment file loaded"
fi
. $DIR/main.env


###########################################################################
# 1. Install docker
# 2. Install Collabora online / CODE as a docker service
###########################################################################

SCRIPT_DIRECTORY=`dirname $0`
. $SCRIPT_DIRECTORY/main.env
. $SCRIPT_DIRECTORY/installNextcloud.env

RUNNING_DATE_TIME="`date +%Y%m%d%H%M%S`"


DEBIAN_FRONTEND='noninteractive' apt-get update \
       && DEBIAN_FRONTEND='noninteractive' apt-get -qq install \
       apt-transport-https \
       ca-certificates \
       curl \
       docker.io \
       gnupg2 \
       seccomp \
       software-properties-common

# Install hosts apache / nginx
if [ ${WEB_SERVER} != "apache2" ]
then
    echo "Error nginx is not supported"
fi
a2enmod proxy
a2enmod proxy_wstunnel
a2enmod proxy_http
a2enmod ssl
cp $SCRIPT_DIRECTORY/etc/apache2/sites-available/collabora.conf /etc/apache2/sites-available/

# Sed
sed -ie "s/\(ServerName\) .*/\1 collabora.${DOMAIN}/" /etc/apache2/sites-available/collabora.conf

a2ensite collabora
systemctl restart apache2

# Configure Nextcloud : app collabora online
# Systemd service
cp $SCRIPT_DIRECTORY/etc/systemd/system/collabora.service /etc/systemd/system/collabora.service
systemctl daemon-reload

systemctl enable  collabora

/bin/bash $SCRIPT_DIRECTORY/startcollabora.sh
echo "All done, don't forget certbot"
