#!/bin/bash

echo "RUN $(basename "$0") ==="

DIR=$(realpath $(dirname $0)/..)
if [ ! -e $DIR/main.env ]
then
    echo "Please copy in root of NoCloud Auto Installer main.env.sample to main.env and edit it"
    exit 1
else
    echo "Environment file loaded"
fi
. $DIR/main.env

apt-get update

DEBIAN_FRONTEND='noninteractive' apt-get -qq install docker-compose
adduser dockerweb
usermod -aG docker dockerweb
if [ -z "$(docker network ls | grep -w traefik)" ]; then
    docker network create traefik --subnet 172.19.0.1/24
fi


# Logrotate traefik
cat <<EOF > /etc/logrotate.d/traefik
/home/dockerweb/traefik/log/access.log {
    weekly
    rotate ${LOGROTATE:-4}
    compress
    # Do not rotate if empty
    notifempty

    delaycompress
    missingok
}
EOF
systemctl restart logrotate

mkdir -p /home/dockerweb/

# Ajout de la clé maintenance
mkdir -p /home/dockerweb/.ssh/
touch /home/dockerweb/.ssh/authorized_keys
cat id_rsa.pub >> /home/dockerweb/.ssh/authorized_keys
chown -R dockerweb:dockerweb /home/dockerweb/.ssh

cd /home/dockerweb/

git clone https://gitlab.tetras-libre.fr/nocloud/docker/traefik
sed -ie "s/adminemail/${SERVER_ADMIN}/" /home/dockerweb/traefik/traefik.toml

echo "HOST=traefik.${DOMAIN}" > /home/dockerweb/traefik/.env

# TODO generate random password
chown -R dockerweb:dockerweb /home/dockerweb
cd /home/dockerweb/traefik
touch acme.json
chmod 600 acme.json
echo "Update /home/dockerweb/traefik/docker-compose.yml to change htpassword line 29"

bash $DIR/upgrade/traefik_fail2ban.sh
