#!/bin/bash

# Copyright (C) 2017  Tetras Libre <admin@tetras-libre.fr>
# Author: Beniamine, David <David.Beniamine@tetras-libre.fr>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

echo "RUN $(basename "$0") ==="


DIR=$(realpath $(dirname $0)/..)
if [ ! -e $DIR/main.env ]
then
    echo "Please copy in root of NoCloud Auto Installer main.env.sample to main.env and edit it"
    exit 1
else
    echo "Environment file loaded"
fi
. $DIR/main.env

echo -e "\tThe following IPS are banned before maintenance"
bash $DIR/checks/banned.sh

$DIR/utils/configure_base_tools.sh
. $DIR/install/Nextcloud.env
if [ -z "$MODS" ] || [ -z "$MAINTENANCE_LEVEL" ]
then
    echo "Please update your main.env"
    exit 1
fi

# Base system update
aptitude update
if [ "$MAINTENANCE_LEVEL" == "upgrade" ]
then
    aptitude upgrade
else
    unattended-upgrade -d
    apt-get install `apt-get -s dist-upgrade | awk '/^Inst.*Security/{print $2}'`
fi

# Update modules
for mod in $MODS
do
    script="$DIR/upgrade/$mod.sh"
    if [ -f $script ]
    then
        /bin/bash $script
    fi
done
customfile="$DIR/upgrade/Custom.sh"
if [ -f "$customfile" ]
then
    /bin/bash $customfile
fi

bash $DIR/install/ncdu.sh

bash $DIR/install/ccze.sh

bash $DIR/upgrade/Monit.sh

bash $DIR/upgrade/Backups.sh

bash $DIR/checks/rkhunter.sh

# Check docker is running
if [ ! -z "`echo $MODS | grep -i collabora`" ]
then
    docker ps -a
fi

# Restart services
services="`checkrestart | awk '/^service/{print $2} /^systemctl/{print $3}'` \
    $EXTRAS_SERVICES_TO_RESTART"
services="$services $(systemctl  | awk '/php.*fpm/{print $1}')"
[ ! -z "$services" ] && systemctl restart $services
checkrestart

echo -e "\tPlease check that the following services are up and running"
bash $DIR/checks/list_domains.sh

bash $DIR/checks/kernel.sh

echo -e "\tAt the end of maintenance the following IPS are banned"
bash $DIR/checks/banned.sh
echo "Please unban IPs that where not banned before with $DIR/unban.sh"
