#!/bin/bash

echo "RUN $(basename "$0") ==="

DIR=$(realpath $(dirname $0)/..)
if [ ! -e $DIR/main.env ]
then
    echo "Please copy in root of NoCloud Auto Installer main.env.sample to main.env and edit it"
    exit 1
else
    echo "Environment file loaded"
fi
. $DIR/main.env

# Switch to php-fpm
ver=$(php --version | awk '{print $2}' | head -n 1 | cut -d . -f 1,2)
if [ -z "$(dpkg -l | grep fpm)" ]
then
    aptitude install php-fpm
    a2enconf php$ver-fpm.conf
    a2enmod rewrite
    a2enmod proxy
    a2enmod proxy_fcgi
    a2dismod php$ver
    cp /etc/php/$ver/fpm/php.ini /etc/php/$ver/fpm/php.ini.bak
    cp /etc/php/$ver/apache2/php.ini /etc/php/$ver/fpm/
    sed -ie 's/^memory_limit.*/memory_limit = 512M/' /etc/php/$ver/fpm/php.ini
    apache2ctl graceful
    systemctl restart php$ver-fpm
    aptitude purge libapache2-mod-php
fi
if [ -z "$(dpkg -l | grep php-bcmath)" ]
then
    aptitude install php-bcmath
fi
# Increase max_children
sed -ie 's/\(pm.max_children =\) 5/\1 20/' /etc/php/$ver/fpm/pool.d/www.conf
systemctl restart php$ver-fpm


if [ -z "$(grep "SSLProtocol.*-TLSv1" /etc/letsencrypt/options-ssl-apache.conf)" ]
then
    sed -i 's/^\(SSLProtocol.*\)$/\1 -TLSv1 -TLSv1.1/' /etc/letsencrypt/options-ssl-apache.conf
    if [ "${WEB_SERVER}" == "apache2" ]
    then
        apache2ctl graceful
    else
        systemctl restart nginx
    fi
fi

if [ -z "$(\ls /etc/apache2/mods-enabled/http2.conf 2>/dev/nul)" ]; then
    echo "Http2 is not enabled, activating, please test using https://tools.keycdn.com/http2-test"
    a2enmod http2
    apache2ctl configtest && apache2ctl graceful
fi
